package cn.yyxx.commsdk.core.network;

import static cn.yyxx.commsdk.core.network.Hosts.HOST;

import android.app.Activity;
import android.content.Context;
import android.text.TextUtils;
import android.util.Log;

import org.json.JSONException;
import org.json.JSONObject;

import cn.yyxx.commsdk.base.internal.ICallback;
import cn.yyxx.commsdk.base.internal.IRequestCallback;

import cn.yyxx.commsdk.base.utils.Logger;
import cn.yyxx.commsdk.core.SdkDrive;
import cn.yyxx.commsdk.core.common.CommonOperationManager;
import cn.yyxx.commsdk.core.utils.ManifestUtils;
import cn.yyxx.commsdk.core.utils.SignUtils;
import cn.yyxx.support.PropertiesUtils;
import cn.yyxx.support.device.DeviceInfoUtils;
import cn.yyxx.support.encryption.aes.AesUtils;
import cn.yyxx.support.encryption.rsa.RsaUtils;

public class SdkRequest {
    private static volatile SdkRequest mInstance;

    private SdkRequest(){}
    public static SdkRequest getInstance(){
        if (mInstance == null){
            synchronized (SdkRequest.class){
                mInstance = new SdkRequest();
            }
        }
        return mInstance;
    }

    public void initAgreement(Context context, IRequestCallback callback){
        String game_code = PropertiesUtils.getValue4Properties(context,"yyxx_cfg.properties","yyxx_game","YYXX_GAME_CODE");
        String gcp_code = ManifestUtils.getMetaDataValue(context,"gcp_code");
        JSONObject json = new JSONObject();
        try {
            json.put("game_code",game_code);
            json.put("gcp_code",gcp_code);
            json.put("route_path", Hosts.BASIC_URL_INIT_AGREEMENT);

        } catch (JSONException e) {
            e.printStackTrace();
        }

        String paramText = SdkDrive.getInstance().invokeJobWithoutParams(json.toString());
        VolleyRequest.post(context,HOST,paramText,callback);
    }
    public void  initSdk(Context context, IRequestCallback callback){

        JSONObject ifa_info = CommonOperationManager.getInstance().getIfa(context);

        try {
            ifa_info.put("route_path",Hosts.BASIC_URL_INIT_SDK);
        } catch (JSONException e) {
            e.printStackTrace();
        }

        String paramText = SdkDrive.getInstance().invokeJob(ifa_info.toString());
        VolleyRequest.post(context,HOST,paramText,callback);
    }

    public void reigsterAccount(Context context, String account,String password,IRequestCallback callback){

        JSONObject json = new JSONObject();

        String uname_pwd = SdkDrive.getInstance().invokeEncryptRsa(account + "|" +password);

        try {
            json.put("route_path",Hosts.BASIC_URL_FAST_REGISTER);
            json.put("smt_type",CommonOperationManager.initBean.isEmulator);
            json.put("uname_pwd",uname_pwd);
        } catch (JSONException e) {
            e.printStackTrace();
        }



        String paramText = SdkDrive.getInstance().invokeJob(json.toString());

        VolleyRequest.post(context,HOST,paramText,callback);
    }

    public void accountLogin(Context context, String account,String password,String login_token,IRequestCallback callback){

        JSONObject json = new JSONObject();

        try {
            json.put("route_path",Hosts.BASIC_URL_USER_LOGIN);
            json.put("smt_type",CommonOperationManager.initBean.isEmulator);

            if (TextUtils.isEmpty(password)){

                json.put("login_token",login_token);

            }else{

                String uname_pwd = SdkDrive.getInstance().invokeEncryptRsa(account + "|" +password);
                json.put("uname_pwd",uname_pwd);
            }

        } catch (JSONException e) {
            e.printStackTrace();
        }



        String paramText = SdkDrive.getInstance().invokeJob(json.toString());

        VolleyRequest.post(context,HOST,paramText,callback);
    }

    public void getPhoneCaptcha(Context context,String phoneNum,String action,IRequestCallback callback){
        JSONObject json = new JSONObject();

        try {
            json.put("route_path",Hosts.BASIC_URL_GET_CAPTCHA);
            json.put("phone",phoneNum);
            json.put("action",action);

        } catch (JSONException e) {
            e.printStackTrace();
        }



        String paramText = SdkDrive.getInstance().invokeJob(json.toString());

        VolleyRequest.post(context,HOST,paramText,callback);
    }


    public void phoneLoginWithSms(Context context,String phoneNum,String code,IRequestCallback callback){
        JSONObject json = new JSONObject();

        try {
            json.put("route_path",Hosts.BASIC_URL_SMS_LOGIN);
            json.put("phone",phoneNum);
            json.put("sms",code);

        } catch (JSONException e) {
            e.printStackTrace();
        }



        String paramText = SdkDrive.getInstance().invokeJob(json.toString());

        VolleyRequest.post(context,HOST,paramText,callback);
    }

    public void setPassword(Context context, String account, String password,String code, IRequestCallback callback){

        JSONObject json = new JSONObject();

        String uname_pwd = SdkDrive.getInstance().invokeEncryptRsa(account + "|" +password);

        try {
            json.put("route_path",Hosts.BASIC_URL_PHONE_REGISTER);
            json.put("smt_type",CommonOperationManager.initBean.isEmulator);
            json.put("sms",code);
            json.put("uname_pwd",uname_pwd);
        } catch (JSONException e) {
            e.printStackTrace();
        }



        String paramText = SdkDrive.getInstance().invokeJob(json.toString());

        VolleyRequest.post(context,HOST,paramText,callback);

    }

    public void resetPassword(Context context, String phoneNum, String password,String code, IRequestCallback callback){

        JSONObject json = new JSONObject();

        String phone_pwd = SdkDrive.getInstance().invokeEncryptRsa(phoneNum + "|" +password + "|" +code);

        try {
            json.put("route_path",Hosts.BASIC_URL_PHONE_RESETPWD);
            json.put("phone_pwd",phone_pwd);
        } catch (JSONException e) {
            e.printStackTrace();
        }



        String paramText = SdkDrive.getInstance().invokeJob(json.toString());

        VolleyRequest.post(context,HOST,paramText,callback);

    }

}
